  * ``id``
  * ``billing_detail_first_name``
  * ``billing_detail_last_name``
  * ``billing_detail_street``
  * ``billing_detail_city``
  * ``billing_detail_state``
  * ``billing_detail_postcode``
  * ``billing_detail_country``
  * ``billing_detail_phone``
  * ``billing_detail_email``
  * ``shipping_detail_first_name``
  * ``shipping_detail_last_name``
  * ``shipping_detail_street``
  * ``shipping_detail_city``
  * ``shipping_detail_state``
  * ``shipping_detail_postcode``
  * ``shipping_detail_country``
  * ``shipping_detail_phone``
  * ``additional_instructions``
  * ``time``
  * ``key``
  * ``user_id``
  * ``shipping_type``
  * ``shipping_total``
  * ``tax_type``
  * ``tax_total``
  * ``item_total``
  * ``discount_code``
  * ``discount_total``
  * ``total``
  * ``transaction_id``
  * ``status``